/**
  *  \file client/tiles/basetech.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/basetech.h"
#include "util/nls.h"
#include "ui/widgets.h"
#include "util/misc.h"
#include "game/planet.h"

/***************************** WBaseTechTile *****************************/

WBaseTechTile::WBaseTechTile(GObjectType& type)
    : WObjectTypeObserverTile(GfxPoint(315, 4 * font_heights[FONT_NORMAL]), type)
{
    setLayout(RightJustified, 0, false);
    addControl(GfxRect(0,  0, 20, 20), h.add(new UIButton("T", 't')));
    addControl(GfxRect(0, 25, 20, 20), h.add(new UIButton("D", 'd')));
}

void
WBaseTechTile::drawBaseTechTile(UIAbstractTableWriter& tw)
{
    GPlanet* p = dynamic_cast<GPlanet*>(getObject());
    if (!p)
        return;

    tw.newLColumn();
    tw.writeFixedCell(UIColor::tc_Static, _("Engines:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Hulls:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Beam Weapons:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Torpedoes:"));

    tw.newRColumn(2 * font_ems[FONT_NORMAL]);
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTech(tl_Engine)));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTech(tl_Hull)));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTech(tl_Beam)));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTech(tl_Torpedo)));

    tw.newLColumn(5);

    tw.newLColumn();
    tw.writeFixedCell(UIColor::tc_Static, _("Defense:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Fighters:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Damage:"));

    tw.newRColumn(fonts[FONT_NORMAL]->getTextWidth(_("none")));

    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getStructures(str_BaseDefense)));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getCargo(el_Fighters)));
    if (p->getBaseDamage()) {
        tw.writeVariableCell(UIColor::tc_Red, itoa(p->getBaseDamage()) + "%");
    } else {
        tw.writeVariableCell(UIColor::tc_Green, _("none"));
    }

    tw.finish();
}

void
WBaseTechTile::drawData(GfxCanvas& can)
{
    UITableWriter tw(can, getSkin(), getInnerSize(5, 0), FONT_NORMAL, 0);
    drawBaseTechTile(tw);
}

