/**
  *  \file client/tiles/minepassage.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/minepassage.h"
#include "game/mine.h"
#include "util/nls.h"
#include "cpluslib/format.h"
#include "game/team.h"

/************************* WMinefieldPassageTile *************************/

WMinefieldPassageTile::WMinefieldPassageTile(GObjectType& type)
    : WObjectTypeObserverTile(font_sizes[FONT_NORMAL].scaledBy(28, 2), type),
      button_inc("+", '+'),
      button_dec("-", '-')
{
    conn_scroll = type.sig_pos_changed.add(this, &WMinefieldPassageTile::onScroll);
    onScroll();

    const int h = font_heights[FONT_NORMAL];
    setLayout(RightJustified, 0, true);
    button_inc.setState(UIButton::bf_SmallSize, true);
    button_dec.setState(UIButton::bf_SmallSize, true);
    addControl(GfxRect(0, 0, h-1, h-1), button_inc);
    addControl(GfxRect(0, h, h-1, h-1), button_dec);
}

void
WMinefieldPassageTile::drawData(GfxCanvas& can)
{
    // |----12em-----|------16em----------------|
    // Safe passage:  32 ly - 72.5%           [+]
    //                32 ly - 85.2% (cloaked) [-]

    GfxRect pos  = getInnerSize(0, 0);
    const int dy = font_heights[FONT_NORMAL];
    const int x0 = 0;
    const int x1 = font_ems[FONT_NORMAL]*12;
    const int w  = pos.w - x1;
    int y = 0;

    GMinefield* mf = dynamic_cast<GMinefield*>(getObject());
    if (!mf)
        return;

    setColor(UIColor::tc_Static);

    // Lines 1+2:
    outText (can, FONT_NORMAL, x0, y, _("Successful passage:"));
    outTextF(can, FONT_NORMAL, x1, y, w,
             format(_("%d ly - %.1f%%"),           move_radius, 100.0 * mf->getPassRate(move_radius, false, getPlayerId())));
    y += dy;
    outTextF(can, FONT_NORMAL, x1, y, w,
             format(_("%d ly - %.1f%% (cloaked)"), move_radius, 100.0 * mf->getPassRate(move_radius, true, getPlayerId())));
    /* y += dy; */
}

void
WMinefieldPassageTile::setMoveRadius(int n)
{
    // Range check
    if (n < 0)
        n = 0;
    if (n > 1000 /* FIXME */)
        n = 1000;

    // Set
    if (n != move_radius) {
        move_radius = n;
        drawWidget();
    }
}

void
WMinefieldPassageTile::onScroll()
{
    if (GMinefield* mf = dynamic_cast<GMinefield*>(getObject()))
        setMoveRadius(mf->getRadius());
}

bool
WMinefieldPassageTile::handleEvent(const UIEvent& e, bool second_pass)
{
    if (e.type == ev_Key) {
        switch (e.key.code) {
         case '+':
            setMoveRadius(move_radius+10);
            return true;
         case '-':
            setMoveRadius(move_radius-10);
            return true;
         case '+' + ss_Shift:
            setMoveRadius(move_radius+1);
            return true;
         case '-' + ss_Shift:
            setMoveRadius(move_radius-1);
            return true;
        }
    }
    return WObjectTypeObserverTile::handleEvent(e, second_pass);
}
