/**
  *  \file client/tiles/objheader.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/objheader.h"
#include "game/obj.h"
#include "gfx/palette.h"
#include "client/marks.h"

/************************* WObjectTypeHeaderTile *************************/

WObjectTypeHeaderTile::WObjectTypeHeaderTile(GObjectType& type)
    : WObjectTypeObserverTile(font_sizes[FONT_NORMAL].scaledBy(20, 1), type),
      button_next(0, "\037", SDLK_PAGEUP),
      button_prev(0, "\036", SDLK_PAGEDOWN)
{
    static const int h = font_heights[FONT_NORMAL];
    setLayout(RightJustified, 0, false);
    button_prev.setState(UIButton::bf_SmallSize, true);
    button_prev.addCall(this, &WObjectTypeHeaderTile::onPrev);
    button_next.setState(UIButton::bf_SmallSize, true);
    button_next.addCall(this, &WObjectTypeHeaderTile::onNext);
    addControl(GfxRect(0, 0, h-1, h-1), button_next);
    addControl(GfxRect(h, 0, h-1, h-1), button_prev);
}

void
WObjectTypeHeaderTile::drawData(GfxCanvas& can)
{
    string_t name;
    bool mark = false;
    if (GObject* o = getObject()) {
        name = o->getFullName();
        name += ":";
        mark = o->isMarked();
    }

    int ofs = 0;
    if (mark) {
        UISkin& sk = getSkin();
        sk.drawBackground(can, GfxRect(extent.x, extent.y, 15, font_heights[FONT_NORMAL]));
        sk.getParameters().color = standard_colors[COLOR_GREENBLACK];
        drawSelection(can, sk, GfxPoint(extent.x + 5, extent.y + 7), 1, 2);
        ofs = 15;
    }

    setColor(UIColor::tc_Static);
    outTextF(can, FONT_NORMAL, ofs, 0, extent.w - 2*font_heights[FONT_NORMAL] - ofs, name);
}

void
WObjectTypeHeaderTile::getLayoutInfo(LayoutInfo& info)
{
    WObjectTypeObserverTile::getLayoutInfo(info);
    info.flags |= li_FlexibleH;
}

void
WObjectTypeHeaderTile::onNext()
{
    GObjectType& t = getType();
    t.setCurrent(t.getNextWrap(t.getCurrent(), false));
}

void
WObjectTypeHeaderTile::onPrev()
{
    GObjectType& t = getType();
    t.setCurrent(t.getPreviousWrap(t.getCurrent(), false));
}
