/**
  *  \file int/context.cc
  *  \brief Interpreter: Contexts
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/context.h"
#include "int/exec.h"
#include "int/intglobal.h"

/* We assume nil is negative. Otherwise, we'd have to convert in lookup(). */
CTASSERT(IntVariableNames::nil < 0);

/**************************** IntSingleContext ***************************/

bool
IntSingleContext::next()
{
    return false;
}

/************************ IntExecutionFrameContext ***********************/

IntExecutionFrameContext::IntExecutionFrameContext(IntExecutionFrame& frame)
    : frame(frame)
{ }

IntExecutionFrameContext::~IntExecutionFrameContext()
{ }

int32_t
IntExecutionFrameContext::lookup(string_t name)
{
    return frame.local_names.lookup(name);
}

void
IntExecutionFrameContext::set(int32_t index, IntValue* name)
{
    frame.local_values.set(index, name);
}

IntValue*
IntExecutionFrameContext::get(int32_t index)
{
    return IntValue::cloneOf(frame.local_values[index]);
}

IntExecutionFrameContext*
IntExecutionFrameContext::clone()
{
    return new IntExecutionFrameContext(frame);
}

GObject*
IntExecutionFrameContext::getObject()
{
    return 0;
}
