/**
  *  \file client/widgets/statictext.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/statictext.h"
#include "ui/uiglobal.h"
#include "gfx/palette.h"

/** \class UIStaticText
    \brief Static line of text

    This widget can display a particular piece of text in one of several
    styles. */

static const int text_types[] = {
    FONT_TITLE,
    FONT_NORMAL,
    FONT_TITLE,
    FONT_TITLE,
    FONT_NORMAL
};
static const int text_colors[] = {
    COLOR_BLACK,
    COLOR_BLACK,
    COLOR_GREENSCALE + 7,
    COLOR_WHITE,
    COLOR_WHITE
};

UIStaticText::UIStaticText(const string_t& text, Scheme scheme, int align)
    : UIWidget(0), text(text), scheme(scheme), align(align)
{
    setState(st_Disabled, true);
}

UIStaticText::UIStaticText(const char* text, Scheme scheme, int align)
    : UIWidget(0), text(text), scheme(scheme), align(align)
{
    setState(st_Disabled, true);
}

void
UIStaticText::getLayoutInfo(LayoutInfo& info)
{
    info.flags = 0;
    info.min_size = info.pref_size =
        GfxPoint(fonts[text_types[scheme]]->getTextWidth(text),
                 font_heights[text_types[scheme]]);
}

void
UIStaticText::drawContent(GfxCanvas& can)
{
    // FIXME: convert this to use the skin, not just the scheme
    GfxParameters parm;
    parm.color = standard_colors[text_colors[scheme]];
    parm.font = fonts[text_types[scheme]];
    getSkin().drawBackground(can, getExtent());

    int dx = 0;
    if (align != 0)
        dx = (extent.w - parm.font->getTextWidth(text))*align / 2;

    outTextF(can, parm, extent.x + dx, extent.y, extent.w - dx, text);
    can.update(extent);
}

void
UIStaticText::setText(const string_t& text)
{
    this->text = text;
    drawWidget();
}

